# Epigrass
## Epidemiological Geo-referenced Analysis and Simulation system

Epigrass is a Python Library aimed at making the simulation of metapopulation models as easy as possible.
Documentation is available on [Readthedocs](https://epigrass.readthedocs.io/en/latest/).

## Installation
You can install Epigrass directly from PyPi, the Python Package Index


## Getting Started
